==> Mu15v1.db_2.2.5.tar.gz: Mu15v1.db/man/Mu15v1_dbconn.Rd <==
\name{Mu15v1_dbconn}

\alias{Mu15v1_dbconn}
\alias{Mu15v1_dbfile}
\alias{Mu15v1_dbschema}
\alias{Mu15v1_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  Mu15v1_dbconn()
  Mu15v1_dbfile()
  Mu15v1_dbschema(file="", show.indices=FALSE)
  Mu15v1_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{Mu15v1_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{Mu15v1_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{Mu15v1_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{Mu15v1_dbschema} prints the schema definition of the
  package annotation DB.

  \code{Mu15v1_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{Mu15v1_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{Mu15v1_dbfile}: a character string with the path to the
  package annotation DB.

  \code{Mu15v1_dbschema}: none (invisible \code{NULL}).

  \code{Mu15v1_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(Mu15v1_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by Mu15v1_dbconn() was created with:
  dbConnect(SQLite(), dbname=Mu15v1_dbfile(), cache_size=64000, synchronous=0)

  Mu15v1_dbschema()

  Mu15v1_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> Mu15v1.db_2.3.5.tar.gz: Mu15v1.db/man/Mu15v1_dbconn.Rd <==

\name{Mu15v1_dbconn}

\alias{Mu15v1_dbconn}
\alias{Mu15v1_dbfile}
\alias{Mu15v1_dbschema}
\alias{Mu15v1_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  Mu15v1_dbconn()
  Mu15v1_dbfile()
  Mu15v1_dbschema(file="", show.indices=FALSE)
  Mu15v1_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{Mu15v1_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{Mu15v1_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{Mu15v1_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{Mu15v1_dbschema} prints the schema definition of the
  package annotation DB.

  \code{Mu15v1_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{Mu15v1_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{Mu15v1_dbfile}: a character string with the path to the
  package annotation DB.

  \code{Mu15v1_dbschema}: none (invisible \code{NULL}).

  \code{Mu15v1_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(Mu15v1_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by Mu15v1_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=Mu15v1_dbfile(), cache_size=64000,
  synchronous=0)

  Mu15v1_dbschema()

  Mu15v1_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
